@@ -43,10 +43,8 @@ RG = {
     1 : "La longitud debe ser mayor a cero . Ocurre cuando la longitud al crear una contraseña es 0"
 }
 
-SP = {
-    0 : "Necesitas el link de la playlist. Ocurre cuando el link que estas usando no es de una playlist de Spotify"
-}
-
 F = {
-    0 : "Necesitas usar una lista. Ocurre cuando pasas algo diferente del tipo <list> a una funcion"
+    0 : "Necesitas usar una lista. Ocurre cuando pasas algo diferente del tipo <list> a una funcion",
+    1 : "El numero no es valido. Ocurre cuando pasas como parametro un tipo de dato invalido a una funcion.",
+    2 : "Tipo de conversion no valida. Ocurre cuando estas pasando como parametro alguna convercion que no existe."
 }
\ No newline at end of file
